@@ -84,7 +84,7 @@ def parse_mpd_tag_cache(tag_cache, music_dir=''):
             _convert_mpd_data(current, tracks, music_dir)
             current.clear()
 
-        current[key.lower()] = value
+        current[key.lower()] = value.decode('utf-8')
 
     _convert_mpd_data(current, tracks, music_dir)
 
@@ -96,29 +96,55 @@ def _convert_mpd_data(data, tracks, music_dir):
 
     track_kwargs = {}
     album_kwargs = {}
+    artist_kwargs = {}
+    albumartist_kwargs = {}
 
     if 'track' in data:
         album_kwargs['num_tracks'] = int(data['track'].split('/')[1])
         track_kwargs['track_no'] = int(data['track'].split('/')[0])
 
     if 'artist' in data:
-        artist = Artist(name=data['artist'])
-        track_kwargs['artists'] = [artist]
-        album_kwargs['artists'] = [artist]
+        artist_kwargs['name'] = data['artist']
+        albumartist_kwargs['name'] = data['artist']
+
+    if 'albumartist' in data:
+        albumartist_kwargs['name'] = data['albumartist']
 
     if 'album' in data:
         album_kwargs['name'] = data['album']
-        album = Album(**album_kwargs)
-        track_kwargs['album'] = album
 
     if 'title' in data:
         track_kwargs['name'] = data['title']
 
+    if 'musicbrainz_trackid' in data:
+        track_kwargs['musicbrainz_id'] = data['musicbrainz_trackid']
+
+    if 'musicbrainz_albumid' in data:
+        album_kwargs['musicbrainz_id'] = data['musicbrainz_albumid']
+
+    if 'musicbrainz_artistid' in data:
+        artist_kwargs['musicbrainz_id'] = data['musicbrainz_artistid']
+
+    if 'musicbrainz_albumartistid' in data:
+        albumartist_kwargs['musicbrainz_id'] = data['musicbrainz_albumartistid']
+
     if data['file'][0] == '/':
         path = data['file'][1:]
     else:
         path = data['file']
 
+    if artist_kwargs:
+        artist = Artist(**artist_kwargs)
+        track_kwargs['artists'] = [artist]
+
+    if albumartist_kwargs:
+        albumartist = Artist(**albumartist_kwargs)
+        album_kwargs['artists'] = [albumartist]
+    
+    if album_kwargs:
+        album = Album(**album_kwargs)
+        track_kwargs['album'] = album
+
     track_kwargs['uri'] = path_to_uri(music_dir, path)
     track_kwargs['length'] = int(data.get('time', 0)) * 1000
 
