@@ -2,6 +2,7 @@ import asynchat
 import logging
 import multiprocessing
 
+from mopidy import settings
 from mopidy.frontends.mpd.protocol import ENCODING, LINE_TERMINATOR, VERSION
 from mopidy.utils.log import indent
 from mopidy.utils.process import pickle_connection
@@ -22,6 +23,7 @@ class MpdSession(asynchat.async_chat):
         self.client_port = client_socket_address[1]
         self.core_queue = core_queue
         self.input_buffer = []
+        self.authenticated = False
         self.set_terminator(LINE_TERMINATOR.encode(ENCODING))
 
     def start(self):
@@ -46,6 +48,11 @@ class MpdSession(asynchat.async_chat):
 
     def handle_request(self, request):
         """Handle request by sending it to the MPD frontend."""
+        if not self.authenticated:
+            (self.authenticated, response) = self.check_password(request)
+            if response is not None:
+                self.send_response(response)
+                return
         my_end, other_end = multiprocessing.Pipe()
         self.core_queue.put({
             'to': 'frontend',
@@ -69,3 +76,26 @@ class MpdSession(asynchat.async_chat):
         output = u'%s%s' % (output, LINE_TERMINATOR)
         data = output.encode(ENCODING)
         self.push(data)
+
+    def check_password(self, request):
+        """
+        Takes any request and tries to authenticate the client using it.
+
+        :rtype: a two-tuple containing (is_authenticated, response_message). If
+            the response_message is :class:`None`, normal processing should
+            continue, even though the client may not be authenticated.
+        """
+        if settings.MPD_SERVER_PASSWORD is None:
+            return (True, None)
+        command = request.split(' ')[0]
+        if command == 'password':
+            if request == 'password "%s"' % settings.MPD_SERVER_PASSWORD:
+                return (True, u'OK')
+            else:
+                return (False, u'ACK [3@0] {password} incorrect password')
+        if command in ('close', 'commands', 'notcommands', 'ping'):
+            return (False, None)
+        else:
+            return (False,
+                u'ACK [4@0] {%(c)s} you don\'t have permission for "%(c)s"' %
+                {'c': command})
