@@ -12,12 +12,12 @@ Available settings and their default values.
 #:
 #: Default::
 #:
-#:     BACKENDS = (u'mopidy.backends.libspotify.LibspotifyBackend',)
+#:     BACKENDS = (u'mopidy.backends.spotify.SpotifyBackend',)
 #:
 #: .. note::
 #:     Currently only the first backend in the list is used.
 BACKENDS = (
-    u'mopidy.backends.libspotify.LibspotifyBackend',
+    u'mopidy.backends.spotify.SpotifyBackend',
 )
 
 #: The log format used for informational logging.
@@ -77,8 +77,8 @@ LASTFM_PASSWORD = u''
 #:
 #: Default::
 #:
-#:    LOCAL_MUSIC_FOLDER = u'~/music'
-LOCAL_MUSIC_FOLDER = u'~/music'
+#:    LOCAL_MUSIC_PATH = u'~/music'
+LOCAL_MUSIC_PATH = u'~/music'
 
 #: Path to playlist folder with m3u files for local music.
 #:
@@ -86,8 +86,8 @@ LOCAL_MUSIC_FOLDER = u'~/music'
 #:
 #: Default::
 #:
-#:    LOCAL_PLAYLIST_FOLDER = u'~/.mopidy/playlists'
-LOCAL_PLAYLIST_FOLDER = u'~/.mopidy/playlists'
+#:    LOCAL_PLAYLIST_PATH = u'~/.mopidy/playlists'
+LOCAL_PLAYLIST_PATH = u'~/.mopidy/playlists'
 
 #: Path to tag cache for local music.
 #:
@@ -95,8 +95,8 @@ LOCAL_PLAYLIST_FOLDER = u'~/.mopidy/playlists'
 #:
 #: Default::
 #:
-#:    LOCAL_TAG_CACHE = u'~/.mopidy/tag_cache'
-LOCAL_TAG_CACHE = u'~/.mopidy/tag_cache'
+#:    LOCAL_TAG_CACHE_FILE = u'~/.mopidy/tag_cache'
+LOCAL_TAG_CACHE_FILE = u'~/.mopidy/tag_cache'
 
 #: Sound mixer to use. See :mod:`mopidy.mixers` for all available mixers.
 #:
@@ -164,22 +164,36 @@ OUTPUT = u'mopidy.outputs.gstreamer.GStreamerOutput'
 #:     Listens on all interfaces, both IPv4 and IPv6.
 MPD_SERVER_HOSTNAME = u'127.0.0.1'
 
+#: The password required for connecting to the MPD server.
+#:
+#: Default: :class:`None`, which means no password required.
+MPD_SERVER_PASSWORD = None
+
 #: Which TCP port Mopidy's MPD server should listen to.
 #:
 #: Default: 6600
 MPD_SERVER_PORT = 6600
 
-#: Path to the libspotify cache.
+#: Path to the Spotify cache.
 #:
-#: Used by :mod:`mopidy.backends.libspotify`.
-SPOTIFY_LIB_CACHE = u'~/.mopidy/libspotify_cache'
+#: Used by :mod:`mopidy.backends.spotify`.
+SPOTIFY_CACHE_PATH = u'~/.mopidy/spotify_cache'
 
 #: Your Spotify Premium username.
 #:
-#: Used by :mod:`mopidy.backends.libspotify`.
+#: Used by :mod:`mopidy.backends.spotify`.
 SPOTIFY_USERNAME = u''
 
 #: Your Spotify Premium password.
 #:
-#: Used by :mod:`mopidy.backends.libspotify`.
+#: Used by :mod:`mopidy.backends.spotify`.
 SPOTIFY_PASSWORD = u''
+
+#: Do you prefer high bitrate (320k)?
+#:
+#: Used by :mod:`mopidy.backends.spotify`.
+#
+#: Default::
+#:
+#:     SPOTIFY_HIGH_BITRATE = False # 160k
+SPOTIFY_HIGH_BITRATE = False
