@@ -3,7 +3,9 @@ import multiprocessing
 import multiprocessing.dummy
 from multiprocessing.reduction import reduce_connection
 import pickle
-import sys
+
+import gobject
+gobject.threads_init()
 
 from mopidy import SettingsError
 
@@ -17,7 +19,6 @@ def unpickle_connection(pickled_connection):
     (func, args) = pickle.loads(pickled_connection)
     return func(*args)
 
-
 class BaseProcess(multiprocessing.Process):
     def __init__(self, core_queue):
         super(BaseProcess, self).__init__()
@@ -86,3 +87,25 @@ class BaseThread(multiprocessing.dummy.Process):
         self.core_queue.put({'to': 'core', 'command': 'exit',
             'status': status, 'reason': reason})
         self.destroy()
+
+
+class GObjectEventThread(BaseThread):
+    """
+    A GObject event loop which is shared by all Mopidy components that uses
+    libraries that need a GObject event loop, like GStreamer and D-Bus.
+
+    Should be started by Mopidy's core and used by
+    :mod:`mopidy.output.gstreamer`, :mod:`mopidy.frontend.mpris`, etc.
+    """
+
+    def __init__(self, core_queue):
+        super(GObjectEventThread, self).__init__(core_queue)
+        self.name = u'GObjectEventThread'
+        self.loop = None
+
+    def run_inside_try(self):
+        self.loop = gobject.MainLoop().run()
+
+    def destroy(self):
+        self.loop.quit()
+        super(GObjectEventThread, self).destroy()
