@@ -10,15 +10,15 @@ from mopidy import settings
 from mopidy.backends.local import LocalBackend
 
 from tests import data_folder
-from tests.backends.base.library import BaseLibraryControllerTest
+from tests.backends.base.library import LibraryControllerTest
 
-class LocalLibraryControllerTest(BaseLibraryControllerTest, unittest.TestCase):
+class LocalLibraryControllerTest(LibraryControllerTest, unittest.TestCase):
 
     backend_class = LocalBackend
 
     def setUp(self):
-        settings.LOCAL_TAG_CACHE = data_folder('library_tag_cache')
-        settings.LOCAL_MUSIC_FOLDER = data_folder('')
+        settings.LOCAL_TAG_CACHE_FILE = data_folder('library_tag_cache')
+        settings.LOCAL_MUSIC_PATH = data_folder('')
 
         super(LocalLibraryControllerTest, self).setUp()
 
